<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Vælg et program</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Installerede programmer</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Valgfri kommando</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Udfør følgende kommando:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="78"/>
        <source>Application name:</source>
        <translation>Programnavn:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="62"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Disse specielle koder kan bruges i kommandoen:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Repræsenterer ét filnavn&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Repræsenterer flere filnavne&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Repræsenterer én URI af filen&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Repræsenterer flere URI&apos;s&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="98"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Luk ikke terminalen efter at kommandoen er udført</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="88"/>
        <source>Execute in terminal emulator</source>
        <translation>Udfør i terminalemulator</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Brug altid dette program til at åbne denne filtype</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Rediger bogmærker</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="49"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="54"/>
        <source>Location</source>
        <translation>Placering</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="64"/>
        <source>&amp;Add Item</source>
        <translation>&amp;Tilføj bogmærke</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="74"/>
        <source>&amp;Remove Item</source>
        <translation>&amp;Fjern bogmærke</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="20"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Brug træk- og-slip til at arrangere bogmærkerne</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Kør fil</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="42"/>
        <source>&amp;Open</source>
        <translation>&amp;Åbn</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="55"/>
        <source>E&amp;xecute</source>
        <translation>&amp;Kør</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="65"/>
        <source>Execute in &amp;Terminal</source>
        <translation>Kør i &amp;terminal</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="88"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="102"/>
        <source>Remember for next files of this kind</source>
        <translation>Husk til næste fil af denne art</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../filedialog.ui" line="22"/>
        <source>Path:</source>
        <translation>Sti:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="65"/>
        <source>File name:</source>
        <translation>Filnavn:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="85"/>
        <source>File type:</source>
        <translation>Filtype:</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../file-operation-dialog.ui" line="42"/>
        <source>Destination:</source>
        <translation>Mål:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="65"/>
        <source>Processing:</source>
        <translation>Behandler:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="78"/>
        <source>Preparing...</source>
        <translation>Forbereder...</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="85"/>
        <source>Progress:</source>
        <translation>Fremskridt:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="119"/>
        <source>Time remaining:</source>
        <translation>Tid tilbage:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="99"/>
        <source>Files processed:</source>
        <translation>Filer behandlet:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Filegenskaber</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Placering:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="132"/>
        <source>File type:</source>
        <translation>Filtype:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="155"/>
        <source>MIME type:</source>
        <translation>MIME-type:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="195"/>
        <source>File size:</source>
        <translation>Filstørrelse:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="218"/>
        <source>On-disk size:</source>
        <translation>Filstørrelse på disk:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="241"/>
        <source>Last modified:</source>
        <translation>Sidst ændret:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="106"/>
        <source>Link target:</source>
        <translation>Henviser til:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="178"/>
        <source>Open With:</source>
        <translation>Åbn med:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="264"/>
        <source>Last accessed:</source>
        <translation>Senest tilgået:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="287"/>
        <source>Created:</source>
        <translation>Oprettet:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="310"/>
        <source>Contains:</source>
        <translation>Indeholder:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="330"/>
        <source>Emblem:</source>
        <translation>Emblem:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="342"/>
        <source>Choose emblem</source>
        <translation>Vælg emblem</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="361"/>
        <source>Clear emblem</source>
        <translation>Fjern emblem</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="397"/>
        <source>Device Usage:</source>
        <translation>Enhedsforbrug:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="424"/>
        <source>Permissions</source>
        <translation>Tilladelser</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="439"/>
        <source>Ownership</source>
        <translation>Ejerskab</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="473"/>
        <location filename="../file-props.ui" line="528"/>
        <location filename="../file-props.ui" line="642"/>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="457"/>
        <location filename="../file-props.ui" line="511"/>
        <location filename="../file-props.ui" line="590"/>
        <source>Owner:</source>
        <translation>Ejer:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="492"/>
        <source>Access Control</source>
        <translation>Filrettigheder</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="545"/>
        <location filename="../file-props.ui" line="694"/>
        <source>Other:</source>
        <translation>Andet:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="562"/>
        <source>Make the file executable</source>
        <translation>Gør filen kørbar</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="603"/>
        <location filename="../file-props.ui" line="655"/>
        <location filename="../file-props.ui" line="707"/>
        <source>Read</source>
        <translation>Læs</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="616"/>
        <location filename="../file-props.ui" line="668"/>
        <location filename="../file-props.ui" line="720"/>
        <source>Write</source>
        <translation>Skriv</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="629"/>
        <location filename="../file-props.ui" line="681"/>
        <location filename="../file-props.ui" line="733"/>
        <source>Execute</source>
        <translation>Udfør</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="749"/>
        <source>Sticky</source>
        <translation>Klæbrig</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="756"/>
        <source>SetUID</source>
        <translation>Indstil bruger-ID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="763"/>
        <source>SetGID</source>
        <translation>Indstil brugergruppe-ID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="792"/>
        <source>Advanced Mode</source>
        <translation>Avanceret Tilstand</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../appchoosercombobox.cpp" line="66"/>
        <source>Customize</source>
        <translation>Tilpas</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../appchooserdialog.cpp" line="268"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>Vælg et program til at åbne filer af typen &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../createnewmenu.cpp" line="62"/>
        <source>Folder</source>
        <translation>Mappe</translation>
    </message>
    <message>
        <location filename="../createnewmenu.cpp" line="66"/>
        <source>Blank File</source>
        <translation>Tom fil</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../core/dirlistjob.cpp" line="48"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation>Den specificerede mappe &apos;%1&apos; er ikke gyldig</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="84"/>
        <source>Loading...</source>
        <translation>Indlæser...</translation>
    </message>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="267"/>
        <location filename="../dirtreemodelitem.cpp" line="311"/>
        <location filename="../dirtreemodelitem.cpp" line="409"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;Ingen undermapper&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../dirtreeview.cpp" line="217"/>
        <source>Open in New T&amp;ab</source>
        <translation>Åbn i nyt &amp;faneblad</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="221"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Åbn i nyt &amp;vindue</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="226"/>
        <source>Open in Termina&amp;l</source>
        <translation>Åbn i termina&amp;l</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>Kopier her</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>Flyt her</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>Opret symbolsk henvisning her</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cannot drop here</source>
        <translation>Kan ikke indsætte her</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../editbookmarksdialog.cpp" line="84"/>
        <source>New bookmark</source>
        <translation>Nyt bogmærke</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../execfiledialog.cpp" line="40"/>
        <source>This file &apos;%1&apos; seems to be a desktop entry.
What do you want to do with it?</source>
        <translation>Filen &apos;%1&apos; ser ud til at være en skrivebordspost.
Hvad vil du gøre med den?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="46"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>Denne tekstfil &quot;%1&quot; er tilsyneladende et kørbart script.
Hvad vil du foretage med det?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="51"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>Denne fil &apos;%1&apos; er kørbar. Vil du køre den ?</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialog</name>
    <message>
        <location filename="../filedialog.cpp" line="115"/>
        <source>Go Back</source>
        <translation>Gå tilbage</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="116"/>
        <source>Alt+Left</source>
        <comment>Go Back</comment>
        <translation>Alt+Venstre</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="122"/>
        <source>Go Forward</source>
        <translation>Gå fremad</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="123"/>
        <source>Alt+Right</source>
        <comment>Go Forward</comment>
        <translation>Alt+Højre</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="130"/>
        <source>Reload</source>
        <translation>Genindlæs</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="131"/>
        <source>F5</source>
        <comment>Reload</comment>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="148"/>
        <source>Create Folder</source>
        <translation>Opret mappe</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="164"/>
        <source>Icon View</source>
        <translation>Ikonvisning</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="168"/>
        <source>Thumbnail View</source>
        <translation>Miniaturevisning</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="172"/>
        <source>Compact View</source>
        <translation>Kompakt visning</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="176"/>
        <source>Detailed List View</source>
        <translation>Detaljeret listevisning</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="184"/>
        <source>Icon Sizes</source>
        <translation>Ikonstørrelser</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="186"/>
        <source>Size of big icons:</source>
        <translation>Størrelse på store ikoner:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="193"/>
        <source>Size of small icons:</source>
        <translation>Størrelse på små ikoner:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="200"/>
        <source>Size of thumbnails:</source>
        <translation>Størrelse på miniaturer:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="216"/>
        <source>Show Hidden</source>
        <translation>Vis skjulte</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="228"/>
        <source>Show Thumbnails</source>
        <translation>Vis miniaturer</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="233"/>
        <source>Show File Tooltips</source>
        <translation>Vis værktøjstips for filer</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="240"/>
        <source>Smooth Scrolling</source>
        <translation>Jævn rulning</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="255"/>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="605"/>
        <location filename="../filedialog.cpp" line="1064"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="605"/>
        <source>Please select a file</source>
        <translation>Vælg venligst en fil</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="681"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 findes allerede.
Vil du erstatte den?</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1026"/>
        <source>Path &quot;%1&quot; does not exist</source>
        <translation>Stien &quot;%1&quot; findes ikke</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1040"/>
        <source>&quot;%1&quot; is not a directory</source>
        <translation>&quot;%1&quot; er ikke en mappe</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1050"/>
        <source>&quot;%1&quot; is not a file</source>
        <translation>&quot;%1&quot; er ikke en fil</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1204"/>
        <location filename="../filedialog.cpp" line="1321"/>
        <source>&amp;Open</source>
        <translation>&amp;Åben</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1207"/>
        <location filename="../filedialog.cpp" line="1329"/>
        <source>&amp;Save</source>
        <translation>&amp;Gem</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1214"/>
        <source>All Files (*)</source>
        <translation>Alle filer (*)</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogHelper</name>
    <message>
        <location filename="../filedialoghelper.cpp" line="140"/>
        <source>Open File</source>
        <translation>Åbn fil</translation>
    </message>
    <message>
        <location filename="../filedialoghelper.cpp" line="141"/>
        <source>Save File</source>
        <translation>Gem fil</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogIconSizeAction</name>
    <message>
        <location filename="../filedialog_p.h" line="40"/>
        <source> px</source>
        <translation> px</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../filemenu.cpp" line="86"/>
        <source>Open</source>
        <translation>Åben</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="90"/>
        <source>Open With...</source>
        <translation>Åben med...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="419"/>
        <source>Many files</source>
        <translation>Mange filer</translation>
    </message>
    <message numerus="yes">
        <location filename="../filemenu.cpp" line="420"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>Vil du åbne denne fil?</numerusform>
            <numerusform>Vil du åbne disse %1 filer?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="181"/>
        <source>Other Applications</source>
        <translation>Andre programmer</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="188"/>
        <source>Create &amp;New</source>
        <translation>Opret &amp;ny</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="207"/>
        <source>&amp;Restore</source>
        <translation>&amp;Gendan</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="217"/>
        <source>Cut</source>
        <translation>Klip</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="221"/>
        <source>Copy</source>
        <translation>Kopiér</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="225"/>
        <source>Paste</source>
        <translation>Indsæt</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="229"/>
        <location filename="../filemenu.cpp" line="547"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Smid i papirkurven</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="233"/>
        <source>Rename</source>
        <translation>Omdøb</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="289"/>
        <source>Mount</source>
        <translation>Monter</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="303"/>
        <source>Unmount</source>
        <translation>Afmonter</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="317"/>
        <source>Eject</source>
        <translation>Skub ud</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="338"/>
        <source>Extract to...</source>
        <translation>Udpak til...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="346"/>
        <source>Extract Here</source>
        <translation>Pak ud her</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="353"/>
        <source>Compress</source>
        <translation>Komprimer</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="362"/>
        <source>Properties</source>
        <translation>Egenskaber</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="376"/>
        <source>Trust selected executables</source>
        <translation>Hav tillid til valgte kørbare</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="377"/>
        <source>Trust this executable</source>
        <translation>Hav tillid til denne kørbar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="482"/>
        <source>Output</source>
        <translation>Uddata</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="211"/>
        <location filename="../filemenu.cpp" line="547"/>
        <source>&amp;Delete</source>
        <translation>&amp;Slet</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../fileoperation.cpp" line="317"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="318"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Nogle filer kan ikke smides i papirkurven, fordi det underliggende filsystem ikke understøtter denne funktion.
Vil du slette dem i stedet?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="404"/>
        <location filename="../fileoperation.cpp" line="422"/>
        <source>Confirm</source>
        <translation>Bekræft</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="405"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>
            <numerusform>Vil du slette den valgte fil?</numerusform>
            <numerusform>Vil du slette de valgte filer?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="423"/>
        <source>Do you want to move the selected file(s) to trash can?</source>
        <translation>
            <numerusform>Vil du flytte den valgte fil til papirkurven?</numerusform>
            <numerusform>Vil du flytte de valgte filer til papirkurven?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../fileoperationdialog.cpp" line="46"/>
        <source>Move Files</source>
        <translation>Flyt filer</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="47"/>
        <source>Moving the following files to destination folder:</source>
        <translation>Flytter følgende filer til målmappen:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="50"/>
        <source>Copy Files</source>
        <translation>Kopier filer</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="51"/>
        <source>Copying the following files to destination folder:</source>
        <translation>Kopier følgende filer til målmappen:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="54"/>
        <source>Trash Files</source>
        <translation>Smid filer i papirkurven</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="55"/>
        <source>Moving the following files to trash can:</source>
        <translation>Flytter følgende filer til papirkurven:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="58"/>
        <source>Delete Files</source>
        <translation>Slet filer</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="59"/>
        <source>Deleting the following files:</source>
        <translation>Sletter følgende filer:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="64"/>
        <source>Create Symlinks</source>
        <translation>Opret symbolske henvisninger</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="65"/>
        <source>Creating symlinks for the following files:</source>
        <translation>Opretter symbolske henvisninger for følgende filer:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="68"/>
        <source>Change Attributes</source>
        <translation>Skift filegenskaber</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="69"/>
        <source>Changing attributes of the following files:</source>
        <translation>Skifter filegenskaber for følgende filer:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="74"/>
        <source>Restore Trashed Files</source>
        <translation>Gendan filer fra papirkurven</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="75"/>
        <source>Restoring the following files from trash can:</source>
        <translation>Gendanner følgende filer fra papirkurven:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="149"/>
        <location filename="../fileoperationdialog.cpp" line="155"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../filepropsdialog.cpp" line="167"/>
        <source>View folder content</source>
        <translation>Vis mappens indhold</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="168"/>
        <source>View and modify folder content</source>
        <translation>Vis og ændre mappens indhold</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="172"/>
        <source>Read</source>
        <translation>Læs</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="173"/>
        <source>Read and write</source>
        <translation>Læs og skriv</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="175"/>
        <source>Forbidden</source>
        <translation>Forbudt</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="292"/>
        <source>Files of different types</source>
        <translation>Filer af forskellige typer</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="315"/>
        <location filename="../filepropsdialog.cpp" line="322"/>
        <location filename="../filepropsdialog.cpp" line="329"/>
        <source>N/A</source>
        <translation>I/T</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="333"/>
        <source>Multiple Files</source>
        <translation>Flere filer</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="410"/>
        <source>%p% used</source>
        <translation>%p% anvendt</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="411"/>
        <source>%1 Free of %2</source>
        <translation>%1 ledig af %2</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="457"/>
        <source>no file</source>
        <translation>ingen fil</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="459"/>
        <source>one file</source>
        <translation>en fil</translation>
    </message>
    <message numerus="yes">
        <location filename="../filepropsdialog.cpp" line="461"/>
        <source>%Ln files</source>
        <translation>
            <numerusform>%Ln fil</numerusform>
            <numerusform>%Ln filer</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="495"/>
        <location filename="../filepropsdialog.cpp" line="540"/>
        <source>Select an icon</source>
        <translation>Vælg et ikon</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="497"/>
        <location filename="../filepropsdialog.cpp" line="542"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>Billeder (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="648"/>
        <source>Apply changes</source>
        <translation>Anvend ændringer</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="649"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Vil du anvende disse ændringer rekursivt på alle filer og undermapper?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../filesearchdialog.cpp" line="157"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="157"/>
        <source>You should add at least one directory to search.</source>
        <translation>Du skal mindst vælge en mappe at søge i.</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="164"/>
        <source>Select a folder</source>
        <translation>Vælg en mappe</translation>
    </message>
</context>
<context>
    <name>Fm::FileTransferJob</name>
    <message>
        <location filename="../core/filetransferjob.cpp" line="486"/>
        <source>Cannot copy a directory into itself!</source>
        <translation>Kan ikke kopiere en mappe ind i sig selv!</translation>
    </message>
    <message>
        <location filename="../core/filetransferjob.cpp" line="537"/>
        <source>Cannot create a link on non-native filesystem</source>
        <translation>Kan ikke oprette en lænke på ikke understøttede filsystemer</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../foldermenu.cpp" line="58"/>
        <source>Empty Trash</source>
        <translation>Tøm papirkurven</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="70"/>
        <source>Create &amp;New</source>
        <translation>Opret &amp;ny</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="75"/>
        <source>&amp;Paste</source>
        <translation>&amp;Indsæt</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="89"/>
        <source>Select &amp;All</source>
        <translation>Vælg &amp;alle</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="100"/>
        <source>Sorting</source>
        <translation>Sortering</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="105"/>
        <source>Show Hidden</source>
        <translation>Vis skjulte</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="140"/>
        <source>Folder Pr&amp;operties</source>
        <translation>Mappe&amp;egenskaber</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="183"/>
        <source>Output</source>
        <translation>Uddata</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="205"/>
        <source>By File Name</source>
        <translation>Efter filnavn</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="206"/>
        <source>By Modification Time</source>
        <translation>Efter ændringstidspunkt</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="207"/>
        <source>By Creation Time</source>
        <translation>Efter oprettelsestidspunkt</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="210"/>
        <source>By Deletion Time</source>
        <translation>Efter sletningstidspunkt</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="213"/>
        <source>By File Size</source>
        <translation>Efter filstørrelse</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="214"/>
        <source>By File Type</source>
        <translation>Efter filtype</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="215"/>
        <source>By File Owner</source>
        <translation>Efter filejer</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="216"/>
        <source>By File Group</source>
        <translation>Efter filgruppe</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="222"/>
        <source>Ascending</source>
        <translation>Stigende</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="227"/>
        <source>Descending</source>
        <translation>Faldende</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="244"/>
        <source>Folder First</source>
        <translation>Mapper først</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="252"/>
        <source>Hidden Last</source>
        <translation>Skjulte til sidst</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="260"/>
        <source>Case Sensitive</source>
        <translation>Forskel på store og små bogstaver</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../foldermodel.cpp" line="306"/>
        <source>Location:</source>
        <translation>Placering:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="310"/>
        <source>File type:</source>
        <translation>Filtype:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="315"/>
        <source>File size:</source>
        <translation>Filstørrelse:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="319"/>
        <source>Last modified:</source>
        <translation>Sidst ændret:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="320"/>
        <source>Last accessed:</source>
        <translation>Senest tilgået:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="321"/>
        <source>N/A</source>
        <translation>I/T</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="323"/>
        <source>Created:</source>
        <translation>Oprettet:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="328"/>
        <source>Owner:</source>
        <translation>Ejer:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="329"/>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="396"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="399"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="402"/>
        <source>Size</source>
        <translation>Størrelse</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="405"/>
        <source>Modified</source>
        <translation>Ændringstidspunkt</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="408"/>
        <source>Created</source>
        <translation>Oprettet</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="411"/>
        <source>Deleted</source>
        <translation>Slettet</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="414"/>
        <source>Owner</source>
        <translation>Ejer</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="417"/>
        <source>Group</source>
        <translation>Gruppe</translation>
    </message>
</context>
<context>
    <name>Fm::FolderViewTreeView</name>
    <message>
        <location filename="../folderview.cpp" line="410"/>
        <source>Auto-resize columns</source>
        <translation>Automatisk tilpasning af kolonnernes størrelse</translation>
    </message>
    <message>
        <location filename="../folderview.cpp" line="427"/>
        <source>Visible Columns</source>
        <translation>Synlige kolonner</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Fed</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../mountoperationpassworddialog.cpp" line="42"/>
        <source>&amp;Connect</source>
        <translation>&amp;Forbind</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../pathbar.cpp" line="123"/>
        <source>&amp;Edit Path</source>
        <translation>&amp;Rediger sti</translation>
    </message>
    <message>
        <location filename="../pathbar.cpp" line="126"/>
        <source>&amp;Copy Path</source>
        <translation>&amp;Kopiér sti</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../placesmodel.cpp" line="46"/>
        <source>Places</source>
        <translation>Steder</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="54"/>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="60"/>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="68"/>
        <source>Applications</source>
        <translation>Programmer</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="77"/>
        <source>Network</source>
        <translation>Netværk</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="81"/>
        <source>Devices</source>
        <translation>Enheder</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="136"/>
        <source>Bookmarks</source>
        <translation>Bogmærker</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="227"/>
        <source>Trash</source>
        <translation>Papirkurv</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../placesview.cpp" line="563"/>
        <source>Open in New Tab</source>
        <translation>Åbn i nyt faneblad</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="567"/>
        <source>Open in New Window</source>
        <translation>Åbn i nyt vindue</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="580"/>
        <source>Empty Trash</source>
        <translation>Tøm papirkurven</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="600"/>
        <location filename="../placesview.cpp" line="662"/>
        <source>Hide</source>
        <translation>Skjul</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="617"/>
        <source>Move Bookmark Up</source>
        <translation>Flyt bogmærke op</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="624"/>
        <source>Move Bookmark Down</source>
        <translation>Flyt bogmærke ned</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="629"/>
        <source>Rename Bookmark</source>
        <translation>Omdøb bogmærke</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="633"/>
        <source>Remove Bookmark</source>
        <translation>Fjern bogmærke</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="643"/>
        <location filename="../placesview.cpp" line="676"/>
        <source>Unmount</source>
        <translation>Afmonter</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="647"/>
        <source>Mount</source>
        <translation>Monter</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="653"/>
        <source>Eject</source>
        <translation>Skub ud</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="688"/>
        <source>Show All Entries</source>
        <translation>Vis alle poster</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../renamedialog.cpp" line="58"/>
        <location filename="../renamedialog.cpp" line="77"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Type: %1
Størrelse: %2
Ændringstidspunkt: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="64"/>
        <location filename="../renamedialog.cpp" line="83"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Type: %1
Ændret: %2</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="104"/>
        <source>&amp;Overwrite</source>
        <translation>Over&amp;skriv</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="106"/>
        <source>&amp;Rename</source>
        <translation>&amp;Omdøb</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="116"/>
        <source>&lt;p&gt;&lt;b&gt;The file cannot overwrite itself.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please select another name.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Filen kan ikke overskrive sig selv.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Vælg venligst et andet navn.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../sidepane.cpp" line="46"/>
        <source>Lists</source>
        <translation>Lister</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="47"/>
        <source>Directory Tree</source>
        <translation>Mappetræ</translation>
    </message>
</context>
<context>
    <name>Fm::UntrashJob</name>
    <message>
        <location filename="../core/untrashjob.cpp" line="35"/>
        <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
        <translation>Kan ikke gendanne filen &apos;%s&apos;: oprindelig sti er ukendt</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Monter</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>Forbind &amp;anonymt</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>Forbind som &amp;bruger:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="76"/>
        <source>&amp;Username:</source>
        <translation>&amp;Brugernavn:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="108"/>
        <source>&amp;Password:</source>
        <translation>&amp;Adgangskode:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="89"/>
        <source>&amp;Domain:</source>
        <translation>&amp;Domæne:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>Glem adgangskoden ø&amp;jeblikkeligt</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="137"/>
        <source>Session length is determined by password manager</source>
        <translation>Sessionslængden er bestemt af kodeordshåndteringen</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="140"/>
        <source>Remember password for &amp;this session</source>
        <translation>Husk adgangskoden for &amp;denne session</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="150"/>
        <source>Remember &amp;forever</source>
        <translation>Husk &amp;for evigt</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../utilities.cpp" line="170"/>
        <source>Rename File</source>
        <translation>Omdøb fil</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="171"/>
        <source>Please enter a new name:</source>
        <translation>Indtast venligst et nyt navn:</translation>
    </message>
    <message>
        <location filename="../filelauncher.cpp" line="124"/>
        <location filename="../filepropsdialog.cpp" line="674"/>
        <location filename="../mountoperation.cpp" line="297"/>
        <location filename="../utilities.cpp" line="154"/>
        <location filename="../utilities.cpp" line="318"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="230"/>
        <source>Create Folder</source>
        <translation>Opret mappe</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="231"/>
        <source>Create File</source>
        <translation>Opret fil</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="235"/>
        <source>Please enter a new file name:</source>
        <translation>Indtast venligst et nyt filnavn:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="236"/>
        <source>New file</source>
        <translation>Ny fil</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="240"/>
        <source>Please enter a new folder name:</source>
        <translation>Indtast venligst et nyt mappenavn:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="241"/>
        <source>New folder</source>
        <translation>Ny mappe</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="246"/>
        <source>Enter a name for the new %1:</source>
        <translation>Indtast et navn til det nye %1:</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="692"/>
        <source>Custom Icon Error</source>
        <translation>Fejl ved brugerdefineret ikon</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="41"/>
        <source>The path is not mounted.</source>
        <translation>Stien er ikke monteret.</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="319"/>
        <source>Invalid desktop entry file: &apos;%1&apos;</source>
        <translation>Ugyldig programobjektfil: &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="355"/>
        <source>No default application is set to launch &apos;%1&apos;</source>
        <translation>Der er ikke sat noget standardprogram til at starte &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="396"/>
        <source>Cannot set working directory to &apos;%1&apos;: %2</source>
        <translation>Kan ikke sætte arbejdsmappe til &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location filename="../placesmodelitem.cpp" line="127"/>
        <source>Identifier: </source>
        <translation>Identifikator: </translation>
    </message>
    <message>
        <location filename="../foldermodelitem.cpp" line="61"/>
        <location filename="../foldermodelitem.cpp" line="74"/>
        <source>N/A</source>
        <translation>I/T</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Bekræft for at erstatte filer</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Der er allerede en fil med dette navn i denne mappe.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Vil du erstatte den eksisterende fil?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="76"/>
        <source>with the following file?</source>
        <translation>med den følgende fil?</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>&amp;Filnavn:</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Gør dette for alle eksisterende filer</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Søg i filer</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>Navn/Sted</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Filnavnsmønster:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="44"/>
        <source>*</source>
        <translation>*</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="58"/>
        <source>Use regular expression</source>
        <translation>Brug regulært udtryk</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="71"/>
        <source>Places to Search:</source>
        <translation>Mapper at søge i:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="84"/>
        <source>&amp;Add</source>
        <translation>&amp;Tilføj</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="96"/>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="132"/>
        <source>Search for hidden files</source>
        <translation>Søg efter skjulte filer</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="143"/>
        <source>File Type</source>
        <translation>Filtype</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="149"/>
        <source>Only search for files of following types:</source>
        <translation>Søg kun efter følgende typer:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="155"/>
        <source>Text files</source>
        <translation>Tekstfiler</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="162"/>
        <source>Image files</source>
        <translation>Billedfiler</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="169"/>
        <source>Audio files</source>
        <translation>Lydfiler</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="176"/>
        <source>Video files</source>
        <translation>Videofiler</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="183"/>
        <source>Documents</source>
        <translation>Dokumenter</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="190"/>
        <source>Folders</source>
        <translation>Mapper</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="214"/>
        <source>Content</source>
        <translation>Indhold</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="220"/>
        <source>File contains:</source>
        <translation>Filen indeholder:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="240"/>
        <source>&amp;Use regular expression</source>
        <translation>Brug &amp;regulære udtryk</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="267"/>
        <source>Properties</source>
        <translation>Egenskaber</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="273"/>
        <source>File Size:</source>
        <translation>Filstørrelse:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="281"/>
        <source>Larger than:</source>
        <translation>Større end:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="302"/>
        <location filename="../filesearch.ui" line="346"/>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="307"/>
        <location filename="../filesearch.ui" line="351"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="312"/>
        <location filename="../filesearch.ui" line="356"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="317"/>
        <location filename="../filesearch.ui" line="361"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="325"/>
        <source>Smaller than:</source>
        <translation>Mindre end:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="51"/>
        <source>Case sensitive</source>
        <translation>Forskel på store og små bogstaver</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="125"/>
        <source>Search in subdirectories</source>
        <translation>Søg i undermapper</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="233"/>
        <source>Case sensiti&amp;ve</source>
        <translation>Forskel på store og små &amp;bogstaver</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="377"/>
        <source>Last Modified Time:</source>
        <translation>Sidst ændret:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="385"/>
        <source>Earlier than:</source>
        <translation>Tidligere end:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="402"/>
        <source>Later than:</source>
        <translation>Senere end:</translation>
    </message>
</context>
</TS>
